@@ -70,14 +70,18 @@ sub get_new_id {
 	my $new_obo_id = OBO::XO::OBO_ID->new();
 	croak 'The local idspace is invalid: ', $local_idspace if ($local_idspace !~ /\w+/);
 	$new_obo_id->idspace($local_idspace);
+	
+	#
 	# get the last 'localID'
+	#
 	if ($self->is_empty()){
-		$new_obo_id->localID("0000001"); # use 7 'numeric placeholders'
+		$new_obo_id->localID('0000001'); # use 7 'numeric placeholders'
 	} else {
 		my @arr = sort {$a cmp $b} keys %{$self->{MAP}};
 		$new_obo_id->localID( $self->{MAP}->{$arr[$#arr]}->localID() );
 	}
 	while (!defined ($self -> add( $new_obo_id = $new_obo_id->next_id() ))) {}
+	
 	return $new_obo_id->id_as_string ();
 }
 
@@ -105,7 +109,7 @@ $size = $obo_id_set->size();
 
 if ($obo_id_set->add($id)) { ... }
 
-$new_id = $obo_id_set->get_new_id("XO", "C");
+$new_id = $obo_id_set->get_new_id('XO');
 
 =head1 DESCRIPTION
 
